==> fred-backend-messenger_0.4.0.orig.tar.gz: fred-backend-messenger-0.4.0/messenger/constants.py <==
"""Constants for messenger."""
from enum import Enum, unique
from functools import lru_cache
from typing import TYPE_CHECKING, Dict, Type

# Prevent circular imports
if TYPE_CHECKING:
    from .models import ArchiveRecord, Record


@unique
class TransportMethod(str, Enum):
    """Enum with message transport methods.

    Members:
        EMAIL: Email
        SMS: SMS
        LETTER: Letter
    """

    EMAIL = 'email'
    SMS = 'sms'
    LETTER = 'letter'

    @property  # type: ignore[misc]  # Ignore 'Decorated property not supported'
    @lru_cache()
    def model_cls(self) -> Type['Record']:
        """Return model class which represents a transport method message."""
        from .models import Email, Letter, Sms

        map: Dict[TransportMethod, Type[Record]] = {
            TransportMethod.EMAIL: Email,
            TransportMethod.SMS: Sms,
            TransportMethod.LETTER: Letter,
        }
        return map[self]

    @property  # type: ignore[misc]  # Ignore 'Decorated property not supported'
    @lru_cache()
    def archive_cls(self) -> Type['ArchiveRecord']:
        """Return model class which represents an archived transport method message."""
        from .models import ArchiveEmail, ArchiveLetter, ArchiveSms

        map: Dict[TransportMethod, Type[ArchiveRecord]] = {
            TransportMethod.EMAIL: ArchiveEmail,
            TransportMethod.SMS: ArchiveSms,
            TransportMethod.LETTER: ArchiveLetter,
        }
        return map[self]


@unique
class MessageStatus(str, Enum):
    """Enum of message statuses.

    Members:
        PENDING: Message pending for sending.
        SENT: Message was sucessfully send.
        FAILED: All attempts to send a message failed.
        ERROR: Message contains an error.
        DELIVERED: Message was successfully delivered.
        UNDELIVERED: Message was not delivered.
        CANCELED: Message was canceled.
    """

    PENDING = 'pending'
    SENT = 'sent'
    FAILED = 'failed'
    ERROR = 'error'
    DELIVERED = 'delivered'
    UNDELIVERED = 'undelivered'
    CANCELED = 'canceled'


@unique
class ArchiveMessageStatus(str, Enum):
    """Enum of archived message statuses.

    Members:
        SENT: Message was sucessfully send.
        FAILED: All attempts to send a message failed.
        DELIVERED: Message was successfully delivered.
        UNDELIVERED: Message was not delivered.
        CANCELED: Message was canceled.
    """

    SENT = 'sent'
    FAILED = 'failed'
    DELIVERED = 'delivered'
    UNDELIVERED = 'undelivered'
    CANCELED = 'canceled'


@unique
class ReferenceType(str, Enum):
    """Enum with reference types."""

    CONTACT = 'contact'
    DOMAIN = 'domain'
    NSSET = 'nsset'
    KEYSET = 'keyset'
    REGISTRAR = 'registrar'

==> fred-backend-messenger_0.5.0.orig.tar.gz: fred-backend-messenger-0.5.0/messenger/constants.py <==
"""Constants for messenger."""
from enum import Enum, unique
from functools import lru_cache
from typing import TYPE_CHECKING, Dict, Type

# Prevent circular imports
if TYPE_CHECKING:
    from .models import ArchiveRecord, Record


@unique
class TransportMethod(str, Enum):
    """Enum with message transport methods.

    Members:
        EMAIL: Email
        SMS: SMS
        LETTER: Letter
    """

    EMAIL = 'email'
    SMS = 'sms'
    LETTER = 'letter'

    @property  # type: ignore[misc]  # Ignore 'Decorated property not supported'
    @lru_cache()
    def model_cls(self) -> Type['Record']:
        """Return model class which represents a transport method message."""
        from .models import Email, Letter, Sms

        map: Dict[TransportMethod, Type[Record]] = {
            TransportMethod.EMAIL: Email,
            TransportMethod.SMS: Sms,
            TransportMethod.LETTER: Letter,
        }
        return map[self]

    @property  # type: ignore[misc]  # Ignore 'Decorated property not supported'
    @lru_cache()
    def archive_cls(self) -> Type['ArchiveRecord']:
        """Return model class which represents an archived transport method message."""
        from .models import ArchiveEmail, ArchiveLetter, ArchiveSms

        map: Dict[TransportMethod, Type[ArchiveRecord]] = {
            TransportMethod.EMAIL: ArchiveEmail,
            TransportMethod.SMS: ArchiveSms,
            TransportMethod.LETTER: ArchiveLetter,
        }
        return map[self]


@unique
class MessageStatus(str, Enum):
    """Enum of message statuses.

    Members:
        PENDING: Message pending for sending.
        SENT: Message was sucessfully send.
        FAILED: All attempts to send a message failed.
        ERROR: Message contains an error.
        DELIVERED: Message was successfully delivered.
        UNDELIVERED: Message was not delivered.
        CANCELED: Message was canceled.
    """

    PENDING = 'pending'
    SENT = 'sent'
    FAILED = 'failed'
    ERROR = 'error'
    DELIVERED = 'delivered'
    UNDELIVERED = 'undelivered'
    CANCELED = 'canceled'


@unique
class ArchiveMessageStatus(str, Enum):
    """Enum of archived message statuses.

    Members:
        SENT: Message was sucessfully send.
        FAILED: All attempts to send a message failed.
        DELIVERED: Message was successfully delivered.
        UNDELIVERED: Message was not delivered.
        CANCELED: Message was canceled.
    """

    SENT = 'sent'
    FAILED = 'failed'
    DELIVERED = 'delivered'
    UNDELIVERED = 'undelivered'
    CANCELED = 'canceled'


@unique
class ReferenceType(str, Enum):
    """Enum with reference types.

    Used as an enum of values for `migrate_archive` command.
    """

    CONTACT = 'contact'
    DOMAIN = 'domain'
    NSSET = 'nsset'
    KEYSET = 'keyset'
    REGISTRAR = 'registrar'
